#!/usr/bin/env python
import os
import subprocess
import datetime
from pip._internal.network.session import PipSession
from pip._internal.req import parse_requirements

from setuptools import find_packages
from setuptools import setup

__VERSION__PY = """# Created automatically in setup.py
__version__ = "%s"
"""
version = None
today = datetime.date.today()
year = today.year
month = today.month
day = today.day


def update_version_py():
    if not os.path.isdir(".git"):
        print("This does not appear to be a Git repository.")
        return

    try:
        ci_commit_sha = os.environ["CI_COMMIT_SHORT_SHA"]
        version_string = f"{year}.{month}.{day}+g{ci_commit_sha}"
    except KeyError:
        print("No CI commit version provided. Falling back to git process.")
        try:
            p = subprocess.Popen(
                ["git", "describe", "--abbrev=7", "--dirty", "--always"],
                stdout=subprocess.PIPE,
            )
        except EnvironmentError:
            print("Git did not return 0 - exiting.")
            return
        stdout = p.communicate()[0]
        if p.returncode != 0:
            print("Git did not return 0 - exiting.")
            return

        version_string = stdout.strip()

    global version
    version = version_string
    f = open("src/tic/__version__.py", "w")
    f.write(__VERSION__PY % version_string)
    f.close()
    print("set __version__.py to '%s'" % version_string)


update_version_py()

name_format = "-py3"
requirements_path = os.path.abspath("./src/tic/shared/requirements.txt")

# Installing a tar.gz also runs python setup.py egg_info -
# this code catches that and modifies the requirements file to be the required one if Python 3 install
if os.path.exists("./PKG-INFO"):
    with open("./PKG-INFO") as fo:
        for line in fo.readlines():
            if "Name: tic-services-py3" in line:
                # Set the requirements path for setup.py egg_info
                requirements_path = os.path.abspath("./src/tic/shared/requirements.txt")
if version is None:
    ci_commit_sha = os.environ.get("CI_COMMIT_SHORT_SHA", "0.1")
    version = f"{year}.{month}.{day}+g{ci_commit_sha}"
setup(
    name="tic-services{0}".format(name_format),
    version=version,
    description="TIC Services",
    author="Bit9",
    author_email="support@bit9.com",
    package_dir={"": "src"},
    packages=find_packages("src"),
    package_data={"/usr/share/tic/startup": ["src/tic/startup/start_horizon.sh"]},
    include_package_data=True,
    install_requires=[
        req.requirement
        for req in parse_requirements(requirements_path, session=PipSession())
    ]
    # Requirements are now located at ./src/tic/shared/requirements.txt
)

# Revert the __version__ file.
if not os.path.isdir(".git"):
    print("This does not appear to be a Git repository.")
else:
    f = open("src/tic/__version__.py", "w")
    f.write(__VERSION__PY % "dev")
    f.close()

# to install the python ***cryptography*** package: the following must be installed
# sudo yum install gcc libffi-devel python-devel openssl-devel

# to install ***MySQL-python*** install the following first:
# sudo yum install mysql-devel

# Need uniaccept from https://github.com/icann/uniaccept-python
