from tic.shared.service import TICConfiguration
from tic.shared.utils.db_util import build_postgresql_connection_string


class AuthConfiguration(TICConfiguration):
    def __init__(self, service_port):
        super(AuthConfiguration, self).__init__("auth", service_port)
        self.cache_expiry_in_seconds = None
        self.auth_conn_str = None
        self.statement_timeout_ms = 0
        self.config_changed()

        self.logger.debug("auth service configuration created.")

    def config_changed(self):
        self.cache_expiry_in_seconds = int(
            self.get("cache", "expiry_value_seconds", 14400)
        )  # 4 hrs
        self.statement_timeout_ms = int(
            self.get("postgres", "statement_timeout", default=0)
        )

        db_host = self.get("postgres", "host")
        if self.commit_sha is not None and len(self.commit_sha) > 0:
            db_host = db_host.format(self.commit_sha)

        self.auth_conn_str = build_postgresql_connection_string(
            host=db_host,
            port=self.get("postgres", "port"),
            db=self.get("postgres", "database"),
            username=self.get("postgres", "user"),
            password=self.get("postgres", "password"),
            decrypt=self.get("postgres", "password_encrypted"),
            aws_region=self.get("AWS", "aws_region"),
        )
