"""
This config is for mosaic2
"""

from tic.shared.base_config import BaseConfig
from tic.shared.api_doc_settings import ApiDocSettings
from tic.shared.utils.util import to_bool


class DefenseConfig(BaseConfig):
    def __init__(self, port):
        super().__init__(
            "defense",
            port,
            api_docs_settings=ApiDocSettings(
                "defense", "Defense (CBC) Reputation Frontend"
            ),
        )

        self.logging_stream = self.get("KINESIS_LOGGING_STREAM")
        self.kinesis_logging_enabled = to_bool(self.get("KINESIS_LOGGING_ENABLED"))
        self.submitted_rate = int(self.get("SUBMITTED_RATE"))
        self.new_reputation_cache_name = self.get("REP_DYNAMODB_TABLE_NAME")
        self.defense_timeout = float(self.get("DEFENSE_TIMEOUT"))
        self.defense_batch_timeout = float(self.get("DEFENSE_BATCH_TIMEOUT"))
        self.endpoint_url = self.get("ENDPOINT_URL")
        self.route_prefix = self.get("ROUTE_PREFIX") or ""
        self.ubs_analysis_url = self.get("UBAP_ANALYSIS_URL") or ""

        # This is for localstack
        # The value in the config map looks like: "--endpoint-url=http://localstack:4566"
        # We only want the URL portion
        if self.endpoint_url:
            self.endpoint_url = self.endpoint_url.split("=")[1]

        # This is to remove the trailing '/' in the ingressRoute so it doesn't interfere
        # with the route defaults which require a leading '/'
        if self.route_prefix and self.route_prefix[-1] == "/":
            self.route_prefix = self.route_prefix[:-1]

        self.iris_api_invocation_enabled = to_bool(
            self.get("IRIS_API_INVOCATION_ENABLED", "False")
        )
        self.iris_api_timeout = int(self.get("IRIS_API_TIMEOUT", "10"))  # in seconds
        self.iris_service_url = self.get("IRIS_SERVICE_URL", None)
        self.iris_token = self.get("IRIS_TOKEN", None)

        self.loaded = True
