class LambdaClient(object):
    def __init__(self, boto_session, boto_config=None, endpoint_url=None):
        """

        @param boto_session: Preexisting boto session
        @param boto_config: optional boto config for the sns client
        """

        self.lambda_client = boto_session.client(
            "lambda", config=boto_config, endpoint_url=endpoint_url
        )

    def invoke(self, function_name, payload, alias="Running", async_invocation=True):
        """
        Invoke a lambda function

        @param function_name: function name to publish to
        @param payload: bytes or file data to include in event during invocation
        @param alias: alias of the function to invoke - defaulted to Running for tic env
        @param async_invocation: boolean to indicate async or synchronous execution of lambda function
        """
        resp = self.lambda_client.invoke(
            FunctionName=f'{function_name}:{alias if alias is not None else "LATEST"}',
            InvocationType=("Event" if async_invocation else "RequestResponse"),
            Payload=payload,
        )

        if "FunctionError" in resp:
            raise Exception(
                f'Failed to execute {function_name}:{alias}. {resp["FunctionError"]}.'
            )
