from boto3 import Session
from time import sleep


class IMDSException(Exception):
    def __init__(self, *args):
        super().__init__(*args)


def create_boto_session(region):
    boto_session = Session(region_name=region)
    total_seconds = 0
    num_retries = 0

    # retry 25s- k8s waits 30 before calling first ready_check, 60 before first health_check
    while total_seconds < 25:
        try:
            if boto_session.get_credentials() is not None:
                return boto_session
            else:
                num_retries += 1
        except Exception:
            num_retries += 1

        wait_time = 2**num_retries
        total_seconds += wait_time
        sleep(wait_time)

    raise IMDSException(
        f"Failure to get session credentials from IMDS after {num_retries} attempts"
    )
