import os
from os import environ
from statsd import TCPStatsClient


# StatsDClient wrapper class using TCP protocol
class StatsdClient:
    def __init__(self, prefix, is_govcloud=False, port=None, logger=None):
        self.statsd = None
        self.logger = logger
        statsd_host = None
        statsd_port = None
        if is_govcloud:
            statsd_host = (
                environ.get("TELEGRAF_PROXY_EXTERNAL_DNS")
                if "TELEGRAF_PROXY_EXTERNAL_DNS" in os.environ
                else None
            )
            statsd_port = (
                environ.get("STATSD_PORT") if "STATSD_PORT" in os.environ else port
            )
        else:
            if ("statsd_host" in os.environ) and ("statsd_port" in os.environ):
                statsd_host = environ.get("statsd_host")
                statsd_port = environ.get("statsd_port")

        if logger:
            logger.info(
                f"statsd_prefix={prefix}, statsd_host={statsd_host}, statsd_port={statsd_port}"
            )

        if statsd_host and statsd_port:
            self.statsd = TCPStatsClient(
                host=statsd_host, port=int(statsd_port), prefix=prefix, timeout=0.025
            )
            # add log when statsd_host and statsd_port are still None due to not finding vars in environ
        else:
            logger.info("no statsd_host and statsd_port defined in environ")

    def incr(self, stat, count=1):
        if self.statsd:
            try:
                self.statsd.incr(stat, count)
            except Exception as ex:
                if self.logger:
                    self.logger.warning(f"statsd exception: {str(ex)}")
                self.statsd.close()

    def timing(self, param, param1):
        if self.statsd:
            try:
                self.statsd.timing(param, param1)
            except Exception as ex:
                if self.logger:
                    self.logger.warning(f"statsd exception: {str(ex)}")
                self.statsd.close()
