from datetime import datetime

from .apc_upload_timing import ApcUploadTiming
from ....dto import Dto
from .apc_lookup_timing import ApcLookupTiming
from .bsv_timing import BsvTiming
from .yara_timing import YaraTiming
from ....utils.date_util import from_iso_8601, to_iso_8601


class UbsAnalysisTimingCollection(Dto):
    decode_settings = {
        "apc": lambda x: None
        if x is None
        else ApcLookupTiming.from_dict(x, True, True),
        "bsv": lambda x: None if x is None else BsvTiming.from_dict(x, True, True),
        "yara": lambda x: None if x is None else YaraTiming.from_dict(x, True, True),
        "date_started": lambda x: None if x is None else from_iso_8601(x),
        "date_completed": lambda x: None if x is None else from_iso_8601(x),
    }

    encode_settings = {
        "date_started": lambda x: None if x is None else to_iso_8601(x),
        "date_completed": lambda x: None if x is None else to_iso_8601(x),
    }

    def __init__(
        self,
        sha256: str = None,
        date_started: datetime = None,
        date_completed: datetime = None,
        apc_lookup: ApcLookupTiming = None,
        apc_lookup_poll: ApcLookupTiming = None,
        apc_upload: ApcUploadTiming = None,
        bsv: BsvTiming = None,
        yara: YaraTiming = None,
    ):
        # everything in here should be a UbsAnalysisTiming subclass except sha256.
        self.sha256 = sha256
        self.date_started = date_started
        self.date_completed = date_completed
        self.apc_lookup = apc_lookup
        self.apc_lookup_poll = apc_lookup_poll
        self.apc_upload = apc_upload
        self.bsv = bsv
        self.yara = yara
