from ..models.models import Cust
from ...dto import Dto
from abc import abstractmethod, ABC


class CustomerMetadata(Dto, ABC):
    def __init__(
        self,
        sha256=None,
        sha256_truncated=None,
        original_md5=None,
        original_size=None,
        org_key=None,
        test=False,
    ):
        self.sha256 = sha256
        self.sha256_truncated = sha256_truncated
        self.original_md5 = original_md5
        self.original_size = original_size
        self.test = test
        self.org_key = org_key

    @abstractmethod
    def is_valid(self):
        """
        Checks the validity of the object. False if not overridden with true validation.
        @return: whether or not the metadata obj is valid
        """
        return self.sha256 is not None and self.org_key is not None

    def is_test(self):
        return self.test

    def is_corrupted(self, sha256_truncated):
        return not (
            self.sha256_truncated is None or sha256_truncated == self.sha256_truncated
        )

    def get_cust(self):
        return Cust(
            org_key=self.org_key, search_key=Cust.get_search_key(org_key=self.org_key)
        )

    def get_log_data(self):
        """
        Returns a dictionary of log details
        """

        return self.to_dict(deep=True, encode=True)
