from boto3 import Session
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

from tic.shared.aws.kms_client import KmsClient
from tic.shared.utils.util import to_bool


def build_mysql_connection_string(
    host, port, db, username, password, decrypt=False, aws_region="us-east-1"
):
    password = decrypt_password(password, decrypt, aws_region)

    return "mysql+pymysql://{3}:{4}@{0}:{1}/{2}?binary_prefix=true".format(
        host, port, db, username, password
    )


def build_postgresql_connection_string(
    host, port, db, username, password, decrypt=False, aws_region="us-east-1"
):
    password = decrypt_password(password, decrypt, aws_region)

    return "postgresql://{3}:{4}@{0}:{1}/{2}".format(host, port, db, username, password)


def decrypt_password(password, decrypt, aws_region):
    if to_bool(decrypt):
        kms_client = KmsClient(Session(region_name=aws_region))
        password = kms_client.decrypt_string(password)

    return password


def get_session_factory(connection_string, pool_size=5):
    engine = create_engine(
        connection_string,
        echo=False,
        echo_pool=False,
        pool_size=pool_size,
        max_overflow=20,
        pool_recycle=3600,
    )
    base = declarative_base()
    base.metadata.bind = engine
    return sessionmaker(bind=engine)


def generate_token(host, port, user_name, aws_region):
    session = Session(region_name=aws_region)
    client = session.client("rds")
    return client.generate_db_auth_token(
        DBHostname=host, Port=port, DBUsername=user_name, Region=aws_region
    )
