"""
References for Common File Paths for Users
https://www.microsoft.com/en-us/wdsi/help/folder-variables
https://en.wikipedia.org/wiki/Home_directory
"""

import re

# List of regular expressions representing paths with possible usernames.
FILEPATH_REGEXES = {
    # Linux
    re.compile("/home/([^/]+)/", re.IGNORECASE),
    # Mac OS X
    re.compile("/Users/([^/]+)/", re.IGNORECASE),
    # Windows
    re.compile(r"\\Users\\([^\\]+)\\", re.IGNORECASE),
    re.compile(r"\\Documents and Settings\\([^\\]+)\\", re.IGNORECASE),
    re.compile(r"\\WINNT\\Profiles\\([^\\]+)\\", re.IGNORECASE),
    re.compile(r"\\cygwin\\home\\([^\\]+)\\", re.IGNORECASE),
}


def anonymize_filepath(filepath):
    for regex in FILEPATH_REGEXES:
        match = regex.search(filepath)

        if match:
            return filepath.replace(match.groups()[0], "[USERNAME]")

    # No match - return original
    return filepath
