# Native imports
import json
import logging
import os
import shutil

# Program imports
from tic.ubs.binary_storage_validation.binary_storage_validation import (
    BinaryStorageValidation,
)
import tic.shared.ubs.repository

logger = logging.getLogger()
logger.setLevel(logging.INFO)

rds_cert = (
    "/rds-combined-ca-bundle.pem"
    if "is_govcloud" in os.environ
    else "/rds-ca-2019-root.pem"
)
root_crt = os.path.dirname(tic.shared.ubs.repository.__file__) + rds_cert
shutil.copyfile(root_crt, os.path.expanduser("/tmp/root.crt"))
logger.debug(f"rds_cert: {rds_cert}")

binary_storage_validation = BinaryStorageValidation()


def handler(event, _):
    try:
        for record in event["Records"]:
            for sns_msg in json.loads(record["Sns"]["Message"])["Records"]:
                binary_storage_validation.main(
                    sns_msg["s3"]["bucket"]["name"], sns_msg["s3"]["object"]["key"]
                )
    except Exception as e:
        logger.exception("Uncaught error.")
        raise e
