from ..exceptions import ClientError

from ....shared.utils.parsers.hash import is_valid_sha256


def validate_and_normalize_sha256(sha256s):
    """
    Validate an iterable is all valid sha256s, force lowercase and deduplicate.

    Will raise ClientError in the event of invalid sha256s.

    :param sha256s: Iterable of sha256s.
    :return: List of sha256s validated and normalized
    """

    invalid_sha256s = set()
    valid_sha256s = set()

    for sha256 in sha256s:
        if not is_valid_sha256(sha256):
            invalid_sha256s.add(sha256)
        else:
            valid_sha256s.add(sha256)

    if len(invalid_sha256s) > 0:
        raise ClientError("Invalid sha256s: {}".format(",".join(invalid_sha256s)))

    # Force all sha256s to be lowercase
    sha256s = [s.lower() for s in valid_sha256s]

    return sha256s
