"""
This config is for mosaic2
"""

from tic.shared.base_config import BaseConfig
from tic.shared.api_doc_settings import ApiDocSettings
from tic.shared.utils.util import to_bool
from tic.shared.utils.db_util import build_postgresql_connection_string


class UbsFrontendConfig(BaseConfig):
    def __init__(self, port):
        super().__init__(
            "ubs_frontend",
            port,
            api_docs_settings=ApiDocSettings(
                "ubs", "Universal Binary Store (UBS) Frontend"
            ),
        )
        self.ubs_storage_bucket = self.get("STORAGE_BUCKET")
        self.statsd_metrics_enabled = to_bool(self.get("METRICS_ENABLED"))
        # Create the DB connection
        db = self.get("RDS_DB")
        port = int(self.get("RDS_PORT"))
        user = self.get("RDS_USER")
        password = self.get("RDS_PASSWORD")
        self.statement_timeout_seconds_cache = 25
        self.ubs_reader_conn_str = build_postgresql_connection_string(
            host=self.get("RDS_READER_HOST"),
            port=port,
            db=db,
            username=user,
            password=password,
            decrypt=False,
        )
        self.ubs_reader_conn_str_cache = self.ubs_reader_conn_str
        # TODO: The writer isn't actually needed by this frontend
        self.ubs_writer_conn_str = build_postgresql_connection_string(
            host=self.get("RDS_WRITER_HOST"),
            port=port,
            db=db,
            username=user,
            password=password,
            decrypt=False,
        )
        self.ubs_reader_conn_str_cache = self.ubs_writer_conn_str
        self.ssl_connection_args = {
            "sslmode": self.get("RDS_SSLMODE", default="verify-ca"),
            "application_name": "ubs_frontend",
        }
        sslrootcert = self.get("RDS_SSLROOTCERT")
        self.statement_timeout_ms = int(self.get("STATEMENT_TIMEOUT_MS", 100))
        if sslrootcert is not None:
            self.ssl_connection_args["sslrootcert"] = sslrootcert

        self.s3_endpoint_url = self.get("S3_ENDPOINT_URL")
        if self.s3_endpoint_url:
            self.s3_endpoint_url = "https://" + self.s3_endpoint_url
        self.route_prefix = self.get("ROUTE_PREFIX") or ""

        # This is to remove the trailing '/' in the ingressRoute so it doesn't interfere
        # with the route defaults which require a leading '/'
        if self.route_prefix and self.route_prefix[-1] == "/":
            self.route_prefix = self.route_prefix[:-1]

        self.loaded = True
