from tic.shared.api_doc_settings import ApiDocSettings
from tic.shared.service import TICConfiguration
from tic.shared.utils.db_util import build_postgresql_connection_string


class UbsFrontendConfiguration(TICConfiguration):
    def __init__(self, port):
        super().__init__(
            "ubs_frontend",
            port,
            "ubs",
            api_docs_settings=ApiDocSettings(
                "ubs", "Universal Binary Store (UBS) Frontend"
            ),
        )
        self.ubs_storage_bucket = None
        self.statsd_metrics_enabled = None
        self.ubs_reader_conn_str = None
        self.ubs_writer_conn_str = None
        self.ssl_connection_args = None
        self.statement_timeout_ms = 100
        self.statement_timeout_seconds_cache = 25
        self.aws_region = None
        self.route_prefix = ""
        self.s3_endpoint_url = None
        self.config_changed()

    def config_changed(self):
        self.aws_region = self.config.get("AWS", "aws_region")
        self.ubs_storage_bucket = self.get("frontend", "storage_bucket")
        self.statsd_metrics_enabled = self.get("frontend", "statsd_metrics_enabled")

        reader_host = self.get("ubs_db", "reader_host")
        if self.commit_sha is not None and len(self.commit_sha) > 0:
            reader_host = reader_host.format(self.commit_sha)

        self.ubs_reader_conn_str = build_postgresql_connection_string(
            host=reader_host,
            port=self.get("ubs_db", "port"),
            db=self.get("ubs_db", "db"),
            username=self.get("ubs_db", "user"),
            password=self.get("ubs_db", "password"),
            decrypt=self.get("ubs_db", "pw_encrypted"),
            aws_region=self.get("AWS", "aws_region"),
        )
        reader_host_cache = self.get("ubs_db_cache", "reader_host_cache")
        if self.commit_sha is not None and len(self.commit_sha) > 0:
            reader_host_cache = reader_host_cache.format(self.commit_sha)

        self.ubs_reader_conn_str_cache = build_postgresql_connection_string(
            host=reader_host_cache,
            port=self.get("ubs_db_cache", "port_cache"),
            db=self.get("ubs_db_cache", "db"),
            username=self.get("ubs_db", "user"),
            password=self.get("ubs_db", "password"),
            decrypt=self.get("ubs_db", "pw_encrypted"),
            aws_region=self.get("AWS", "aws_region"),
        )

        writer_host = self.get("ubs_db", "writer_host")
        if self.commit_sha is not None and len(self.commit_sha) > 0:
            writer_host = writer_host.format(self.commit_sha)

        self.ubs_writer_conn_str = build_postgresql_connection_string(
            host=writer_host,
            port=self.get("ubs_db", "port"),
            db=self.get("ubs_db", "db"),
            username=self.get("ubs_db", "user"),
            password=self.get("ubs_db", "password"),
            decrypt=self.get("ubs_db", "pw_encrypted"),
            aws_region=self.get("AWS", "aws_region"),
        )
        #
        writer_host_cache = self.get("ubs_db_cache", "writer_host_cache")  # noqa: F841
        if self.commit_sha is not None and len(self.commit_sha) > 0:
            writer_host_cache = writer_host.format(self.commit_sha)  # noqa: F841

        self.ubs_writer_conn_str_cache = build_postgresql_connection_string(
            host=writer_host,
            port=self.get("ubs_db_cache", "port_cache"),
            db=self.get("ubs_db_cache", "db"),
            username=self.get("ubs_db", "user"),
            password=self.get("ubs_db", "password"),
            decrypt=self.get("ubs_db", "pw_encrypted"),
            aws_region=self.get("AWS", "aws_region"),
        )
        self.statement_timeout_seconds_cache = self.get(
            "ubs_db_cache", "statement_timeout_seconds_cache"
        )

        # FOR AWS: sslmode should be default. ssl_root_cert_path should be '/tmp/root.crt'.
        # FOR LOCAL: usually want ssl_mode to be 'require' and ssl_root_cert_path empty.
        self.ssl_connection_args = {
            "sslmode": self.get("ubs_db", "ssl_mode", default="verify-full")
        }
        sslrootcert = self.get("ubs_db", "ssl_root_cert_path", default=None)
        if sslrootcert is not None:
            self.ssl_connection_args["sslrootcert"] = sslrootcert

        self.statement_timeout_ms = int(self.get("ubs_db", "statement_timeout_ms"))
