from tic.shared.ubs.models.models import CustIxLink, FileIndex, Cust
from sqlalchemy import select
from datetime import datetime, time, timezone
from binascii import hexlify

# Midnight
REPORT_START_TIME = time(0, 0, 0, 0)
# Midnight - 1 microsecond
REPORT_END_TIME = time(23, 59, 59, 999999)


def get_unique_binaries_for_date(date, org_key, reader):
    report_date_start = datetime.combine(date, REPORT_START_TIME, tzinfo=timezone.utc)
    report_end_date = datetime.combine(date, REPORT_END_TIME, tzinfo=timezone.utc)
    report_metadata = {
        "report_date_start": report_date_start.isoformat(),
        "report_end_date": report_end_date.isoformat(),
    }
    results = reader.execute(
        select(FileIndex.sha256, CustIxLink.date_created)
        .join(FileIndex, FileIndex.id == CustIxLink.file_index_id)
        .where(CustIxLink.cust_id == select(Cust.id).where(Cust.org_key == org_key))
        .where(
            CustIxLink.date_created
            >= datetime.combine(date, REPORT_START_TIME, tzinfo=timezone.utc)
        )
        .where(
            CustIxLink.date_created
            <= datetime.combine(date, REPORT_END_TIME, tzinfo=timezone.utc)
        )
    ).all()
    return build_json_dict(report_metadata, results)


def build_json_dict(report_metadata, results):
    results_dict = [
        {"hash": hexlify(x[0]).decode("utf-8"), "ingest_time": x[1].isoformat()}
        for x in results
    ]
    final_results_dict = report_metadata
    final_results_dict["hashes"] = results_dict
    return final_results_dict
