# Native imports
from base64 import b64decode
import json
import logging
import os
import shutil

# Program imports
from tic.shared.utils.lambda_utils.kinesis_lambda_util import KinesisLambdaUtil
from tic.ubs.metadata.ingestion.metadata_ingestion import MetadataIngestion
import tic.shared.ubs.repository

logger = logging.getLogger()
logger.setLevel(logging.INFO)

rds_cert = (
    "/rds-combined-ca-bundle.pem"
    if "is_govcloud" in os.environ
    else "/rds-ca-2019-root.pem"
)

root_crt = os.path.dirname(tic.shared.ubs.repository.__file__) + rds_cert
shutil.copyfile(root_crt, os.path.expanduser("/tmp/root.crt"))
logger.debug(f"rds_cert: {rds_cert}")

metadata_ingestion = MetadataIngestion()


def handler(event, context):
    metadata_ingestion.statsd.incr("kinesis.batch")
    metadata_ingestion.statsd.incr("kinesis.record", len(event["Records"]))

    raw_records = [b64decode(record["kinesis"]["data"]) for record in event["Records"]]

    individual_record_jsons = list()
    for aggregated_record in raw_records:
        # collect individual lines from jsonl as long as not empty at the end of the aggregation
        individual_record_jsons.extend(
            [line for line in aggregated_record.split(b"\n") if line]
        )

    if len(individual_record_jsons) == 0:
        logger.warning("raw records length is 0, exit now")
        return

    # delete me take2
    metadata_ingestion.statsd.incr(
        "post.deaggregation.record", len(individual_record_jsons)
    )

    kinesis_lambda_util = KinesisLambdaUtil(
        metadata_ingestion.dlq_name,
        metadata_ingestion.sqs_client,
        logger,
        metadata_ingestion.statsd,
    )
    try:
        records = [json.loads(record) for record in individual_record_jsons]
    except Exception as ex:
        kinesis_lambda_util.exception_handler(
            ex, in_raw_records=individual_record_jsons
        )
        return

    try:
        metadata_ingestion.main(records, kinesis_lambda_util)
    except Exception as ex:
        kinesis_lambda_util.exception_handler(ex, in_records=records)
