import json

from tic.reputation.shared.enums.reputation_category import ReputationCategory
from tic.shared.dto import DtoEncoder, Dto


class IrisReputationLookupItem(Dto):
    """
    Represents input data item for Iris Api
    """

    def __init__(self):
        self.file_sha256 = None
        self.file_tlsh = None
        self.signature_state = None
        self.signature_publisher = None
        self.cdc_reputation = ReputationCategory.NOT_LISTED.value
        self.request_hash = None


class IrisRequestPayload(Dto):
    """
    Responsible for generating Iris Api payload from input and cdc reputation data
    """

    def __init__(self):
        self.request_id = None
        self.file_reputation_requests = []

    @staticmethod
    def generate(requests, cdc_lookup_results):
        """
        generates Iris payload json
        """
        req_data = IrisRequestPayload()
        req_data.request_id = "abc"
        i = 0

        for req in requests:
            item = IrisReputationLookupItem()
            item.file_sha256 = req["sha256"]
            item.request_hash = f"{i}"
            # don't add to iris api request if there is no TLSH
            if "tlsh" not in req:
                i += 1
                continue

            item.file_tlsh = req["tlsh"]
            if "signature_publisher" in req:
                item.signature_publisher = req["signature_publisher"]
                item.signature_state = req["signature_state"]
            if len(cdc_lookup_results) > 0:
                lookup_item = cdc_lookup_results[i]
                if lookup_item["hash"] == item.file_sha256:
                    rep_category = lookup_item["reputation"]["category"]
                    item.reputation_category = (
                        ReputationCategory.NOT_LISTED
                        if rep_category is None
                        else rep_category
                    )
            i += 1
            req_data.file_reputation_requests.append(item)

        if len(req_data.file_reputation_requests) > 0:
            return json.dumps(req_data, cls=DtoEncoder)

        return None
